function write_env_RAM( ~, ~, TitleEnv, freq, SSP, Bdry, Pos, ~, ~, ~, varargin )

% Write an environmental file
% mbp 2009
% note: I had an unusual case with a parabolic mirror where round-off in
% the receiver ranges was a problem (+/- 1 m in range)
% Changed the output format from %6.2f to %6f to accommodate that.
% Similar issues may occur elsewhere in the code below ...

global xBot NbtyPts

envfil = 'ram.in';
btyfil = 'BTYFIL';
BotBTY = '*';
depthB = 1e9;
rBox   = 1e9;
RMax   = Pos.r.range( end );

fid = fopen( envfil, 'w' );   % create new envfil

zmax = 1.5 * SSP.depth( 2 );   % extend water depth by 50%

% some conservative guesses at the required step size ...
dz = 1500 / freq / 15;   % lamda / 15
dr = 10 * dz;            % this one should be related to the amount of variation in range

% dr = 1000 * ( Pos.r.range( end ) - Pos.r.range( 1 ) ) / length( Pos.r.range );   % range step
% dz =        ( Pos.r.depth( end ) - Pos.r.depth( 1 ) ) / length( Pos.r.range );   % depth step

% round the mesh spacing to be an even divider of the water depth
% nn = round( zmax / dz );
% dz = zmax / nn;
% nn = round( 1001 * RMax / dr ) - 1;
% dr = 1001 * RMax / nn;
% 
% ndr = 1;   % range skip factor
% ndz = 1;   % depth skip factor

ndr = round( ( Pos.r.range( 2 ) - Pos.r.range( 1 ) ) / dr );   % range skip factor
ndz = round( ( Pos.r.depth( 2 ) - Pos.r.depth( 1 ) ) / dz );   % depth skip factor

ndr = max( ndr, 1 );
ndz = max( ndz, 1 );

zmplt = Pos.r.depth( end );

c0 = min( SSP.raw( 1 ).alphaR );   % reference sound speed

np = 8;   % number of Pade terms
ns = 1;   % number of starter terms
rs = 0.0; % range of source?

% header

fprintf( fid, '''%s'' ! Title \r\n', TitleEnv );
fprintf( fid, '%8.2f %8.2f %8.2f \t \t \t ! Frequency (Hz) zs zr \r\n', freq, Pos.s.depth( 1 ), Pos.r.depth( end ) );
fprintf( fid, '%8.2f %8.2f %3i   \t \t \t ! rmax dr ndr \r\n', 1000 * RMax, dr, ndr );
fprintf( fid, '%8.2f %8.2f %3i %8.2f   \t \t \t ! zmax dz ndz zmplt \r\n', zmax, dz, ndz, zmplt );
fprintf( fid, '%8.2f %1i %1i %8.2f   \t \t \t ! c0 np ns rs \r\n', c0, np, ns, rs );

% bathymetry
BotBTY = Bdry.Bot.Opt( 2 : 2 );

if ( exist( btyfil, 'file' ) && BotBTY == '*' )
   readbty( btyfil, BotBTY, depthB, rBox )
else
   NbtyPts = 3;
   clear xBot
   xBot( 1, : ) = [ 0 0 1e9 ];
   xBot( 2, : ) = [ Bdry.Bot.depth Bdry.Bot.depth Bdry.Bot.depth ];
end

for ii = 2 : NbtyPts - 1
   fprintf( fid, '%8.2f %8.2f   \t \t \t ! rb zb \r\n', xBot( 1, ii ), xBot( 2, ii ) );
end
fprintf( fid, '-1 -1 \r\n' );   % terminator

% SSP
for ii = 2 : NbtyPts - 1
   
   if ( ii ~= 2 )
      fprintf( fid, '\t %6.2f \t ! rp \r\n', xBot( 1, ii ) );   % range for this profile
   end
   
   % SSP
   
   medium = 1;
   for jj = 1 : length( SSP.raw( medium ).z )
      fprintf( fid, '\t %6.2f %6.2f \t ! z c \r\n', ...
         [ SSP.raw( medium ).z( ii ) SSP.raw( medium ).alphaR( jj ) ] );
   end
   fprintf( fid, '-1 -1 \r\n' );   % terminator
   
   % Sediment
   fprintf( fid, '    %6.2f %6.2f /  \t ! lower halfspace \r\n', 0.0, Bdry.Bot.HS.alphaR );
   fprintf( fid, '-1 -1 \r\n' );   % terminator
   
   % density
   fprintf( fid, '    %6.2f %6.2f  \t ! lower halfspace \r\n', 0.0, Bdry.Bot.rho );
   fprintf( fid, '-1 -1 \r\n' );   % terminator
   
   % attenuation
   fprintf( fid, '    %6.2f %6.2f  \t ! lower halfspace \r\n', 0.0, Bdry.Bot.HS.alphaI );
   fprintf( fid, '    %6.2f %6.2f  \t ! lower halfspace \r\n', 0.5 * SSP.depth( SSP.NMedia+1 ), Bdry.Bot.HS.alphaI );
   fprintf( fid, '    %6.2f %6.2f  \t ! lower halfspace \r\n', 0.6 * SSP.depth( SSP.NMedia+1 ), 10 );
   fprintf( fid, '-1 -1 \r\n' );   % terminator

end

fclose( fid );

