%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Summer School StrongMAR - 2016
% Time and Frequency Modelling
% Paulo Santos 
% 29th June, 2016
%
% C-TRACEO  Eigenrays and arrival patterns
% pjsantos@ualg.pt
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
!del eig.mat 
clear all%, close all 

case_title = '''STARESO waveguide.''';

%==================================================================
%  
%  Define source data:
%  
%==================================================================

%disp('Defining source characteristics...')

freq   =  1000;
Rmax   =  50;
Dmax   =  11; 

ray_step = Rmax/1000; 

zs       = 8.5;
rs       = 0;
thetamax = 40;
np2      = 4001;
la       = linspace(-thetamax,thetamax,np2);

source_data.ds       = ray_step;
source_data.position = [rs zs];
source_data.rbox     = [-1 Rmax+1];
source_data.f        = freq;
source_data.thetas   = la;

%==================================================================
%  
%  Define altimetry data:
%  
%==================================================================

%disp('Defining surface characteristics...')

altimetry = [-2 Rmax+2;0 0];

surface_data.type  =   '''V'''; 
surface_data.ptype =   '''H'''; % Homogeneous
surface_data.units =   '''W'''; % (Attenuation Units) dB/Wavelenght
surface_data.itype =  '''FL'''; % Sea surface interpolation type
surface_data.x     = altimetry; % Surface coordinates
surface_data.properties = [0 0 0 0 0]; % Dummy values

%==================================================================
%  
%  Define sound speed data:
%  
%==================================================================

%disp('Defining the sound speed profile...')

c0 = 1517;
ssp_data.cdist = '''c(z,z)'''; % Sound speed profile
ssp_data.cclass = '''ISOV'''; % Isovelocity profile
ssp_data.z   = [0 Dmax]';
ssp_data.r   = [];
ssp_data.c   = [c0 c0]';

%==================================================================
%  
%  Define object data:
%  
%==================================================================

object_data.nobjects = 0; % Number of objects

%==================================================================
%  
%  Define bathymetry data:
%  
%==================================================================

%disp('Defining bottom characteristics...')

%bathymetry = [-12, -2, -1.9, Rmax+2;    0, 6, 8.5, 21.5];
bathymetry = [-2, 90, Rmax+1; 
              10, 10, 10];
bottom_data.type   = '''E''' ;
bottom_data.ptype  = '''H''' ; % Homogeneous bottom
bottom_data.units  = '''W''' ; % Bottom attenuation units
bottom_data.itype  = '''2P'''; % Bottom interpolation type 
bottom_data.x      = bathymetry; % Bottom coordinates 
bottom_data.properties = [1750 0.0 1.8 0.7 0]; % [cp cs rho ap as]

%==================================================================
%  
%  Define output data:
%  
%==================================================================

%disp('Defining output options...')

ranges = 50;  depths = [6.5]; %depths = [17.5];

m = length( ranges );
n = length( depths );

output_data.ctype       = '''EPR''';  %      '''ADP'''
output_data.array_shape = '''VRY''';
output_data.r           = ranges;
output_data.z           = depths;
output_data.miss        = 0.02;

%==================================================================
%  
%  Call the function:
%  
%==================================================================

disp('Writing TRACEO waveguide input file...')

wtraceoinfil('flat.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data);

disp('Calling cTraceo...')
!ctraceo flat


disp('Reading the output data...')
load eig

figure, hold on
plot(rs,zs,'ko',rs,zs,'m*','MarkerSize',16) 

[a, b] = size(eigenrays);   %get dimensions of hydrophone array

for rHyd = 1:a  %iterate over hydrophone ranges
    for zHyd = 1:b  %iterate over hydrophone depths
        for i = 1:eigenrays(rHyd,zHyd).nEigenrays   %iterate over eigenrays of hydrphone
            plot(eigenrays(rHyd,zHyd).eigenray(i).r, eigenrays(rHyd,zHyd).eigenray(i).z, 'LineWidth', 1)   
        end
    end
end

%the eigenrays can also be plotted using the included function:
%plotEigenrays(eigenrays)

plot(ranges,depths, 'm*');  %plot hydrophones
plot(bathymetry(1,:), bathymetry(2,:), 'k', 'LineWidth', 2)  %plot the bathymetry
grid on, box on
axis([-2 Rmax 0 Dmax])
view(0,-90)
hold off 
xlabel('Range (m)')
ylabel('Depth (m)')
title('cTRACEO - Eigenrays')
%title('cTraceo - Eigenray Search by Regula Falsi in a Pekeris flat waveguide.')

%%%%
%
% use the same input parameters to compute amp-delays
%
%%%%%%%%
output_data.miss        = 0.01;
output_data.ctype       = '''ADR''';


%==================================================================
%  
%  Call the function:
%  
%==================================================================

disp('Writing TRACEO waveguide input file...')

wtraceoinfil('flat.in',case_title,source_data,surface_data,ssp_data,object_data,bottom_data,output_data);

disp('Calling cTraceo...')
!ctraceo flat

disp('Reading the output data...')

load('aad')

narr=arrivals.nArrivals

theta=[arrivals.arrival(1:narr).theta];
r=[arrivals.arrival(1:narr).r];
z=[arrivals.arrival(1:narr).z];
amp=[arrivals.arrival(1:narr).amp];
tau=[arrivals.arrival(1:narr).tau];

[dummy ind]=find(abs(z-arrivals.zHyd)<0.01);

figure
subplot(211)
stem(tau*1000,real(amp))
hold
stem(tau(ind)*1000,real(amp(ind)),'r')
xlabel('Travel time (ms)')

subplot(212)
%stem(tau*1000,theta)
plot(tau*1000,theta,'b')
hold
%plot(tau(ind)*1000,theta(ind)*180/pi,'or')
stem(tau(ind)*1000,theta(ind)*180/pi,'or')
grid on, box on
xlabel('Travel time (ms)')
ylabel('Angle ()')

